==> kde-workspace-4.10.5.tar.xz: kde-workspace-4.10.5/ksysguard/ksysguardd/NetBSD/Memory.h <==
/*
    KSysGuard, the KDE System Guard
   
	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef _memory_h_
#define _memory_h_

void initMemory(struct SensorModul* sm);
void exitMemory(void);

int updateMemory(void);

void printMFree(const char* cmd);
void printMFreeInfo(const char* cmd);
void printUsed(const char* cmd);
void printUsedInfo(const char* cmd);
void printActive(const char* cmd);
void printActiveInfo(const char* cmd);
void printInactive(const char* cmd);
void printInactiveInfo(const char* cmd);
void printWired(const char* cmd);
void printWiredInfo(const char* cmd);
void printExecpages(const char* cmd);
void printExecpagesInfo(const char* cmd);
void printFilepages(const char* cmd);
void printFilepagesInfo(const char* cmd);
void printSwapUsed(const char* cmd);
void printSwapUsedInfo(const char* cmd);
void printSwapFree(const char* cmd);
void printSwapFreeInfo(const char* cmd);

#endif

==> kde-workspace-4.22.0.tar.xz: kde-workspace-4.22.0/ksysguard/ksysguardd/NetBSD/Memory.h <==
/*
    KSysGuard, the KDE System Guard
   
	Copyright (c) 1999 Chris Schlaeger <cs@kde.org>
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#ifndef _memory_h_
#define _memory_h_

void initMemory(struct SensorModul* sm);
void exitMemory(void);

int updateMemory(void);

void printMFree(const char* cmd);
void printMFreeInfo(const char* cmd);
void printUsed(const char* cmd);
void printUsedInfo(const char* cmd);
void printActive(const char* cmd);
void printActiveInfo(const char* cmd);
void printInactive(const char* cmd);
void printInactiveInfo(const char* cmd);
void printWired(const char* cmd);
void printWiredInfo(const char* cmd);
void printExecpages(const char* cmd);
void printExecpagesInfo(const char* cmd);
void printFilepages(const char* cmd);
void printFilepagesInfo(const char* cmd);
void printAnonpages(const char* cmd);
void printAnonpagesInfo(const char* cmd);
void printApplication(const char* cmd);
void printApplicationInfo(const char* cmd);
void printSwapUsed(const char* cmd);
void printSwapUsedInfo(const char* cmd);
void printSwapFree(const char* cmd);
void printSwapFreeInfo(const char* cmd);

#endif
